# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
from decimal import Decimal
import django.core.validators


class Migration(migrations.Migration):

    dependencies = [
        ('forex', '0008_auto_20150526_1310'),
    ]

    operations = [
        migrations.RenameModel(
            old_name='CurrencyPrices',
            new_name='CurrencyPrice',
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
from decimal import Decimal
import django.core.validators


class Migration(migrations.Migration):

    dependencies = [
        ('forex', '0009_auto_20150529_1110'),
    ]

    operations = [
        migrations.AlterField(
            model_name='currencyprice',
            name='bid_price',
            field=models.DecimalField(default=0, max_digits=20, decimal_places=4, validators=[django.core.validators.MinValueValidator(Decimal('0.00'))]),
            preserve_default=False,
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
        ('forex', '0002_auto_20150508_1326'),
    ]

    operations = [
        migrations.AlterField(
            model_name='currencyprices',
            name='ask_price_us',
            field=models.DecimalField(default=0, editable=False, max_digits=20, decimal_places=4),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name='currencyprices',
            name='bid_price_us',
            field=models.DecimalField(default=0, editable=False, max_digits=20, decimal_places=4),
            preserve_default=False,
        ),
    ]



#!/usr/bin/env python
"""
This script is a trick to setup a fake Django environment, since this reusable
app will be developed and tested outside any specifiv Django project.

Via ``settings.configure`` you will be able to set all necessary settings
for your app and run the tests as if you were calling ``./manage.py test``.

"""
import re
import sys

from django.conf import settings

import coverage
from fabric.api import abort, lcd, local
from fabric.colors import green, red

import forex.settings.test_settings as test_settings


if not settings.configured:
    settings.configure(**test_settings.__dict__)


from django_coverage.coverage_runner import CoverageRunner
from django_nose import NoseTestSuiteRunner


class NoseCoverageTestRunner(CoverageRunner, NoseTestSuiteRunner):
    """Custom test runner that uses nose and coverage"""
    def run_tests(self, *args, **kwargs):
        results = super(NoseCoverageTestRunner, self).run_tests(
            *args, **kwargs)
        coverage._the_coverage.data.write_file('.coverage')
        return results


def runtests(*test_args):
    failures = NoseCoverageTestRunner(verbosity=2, interactive=True).run_tests(
        test_args)

    with lcd(settings.COVERAGE_REPORT_HTML_OUTPUT_DIR):
        total_line = local('grep -n Total index.html', capture=True)
        match = re.search(r'^(\d+):', total_line)
        total_line_number = int(match.groups()[0])
        percentage_line_number = total_line_number + 4
        percentage_line = local(
            'awk NR=={0} index.html'.format(percentage_line_number),
            capture=True)
        match = re.search(r'<td>(\d.+)%</td>', percentage_line)
        percentage = float(match.groups()[0])
    if percentage < 100:
        # abort(red('Coverage is {0}%'.format(percentage)))
        pass
    print(green('Coverage is {0}%'.format(percentage)))

    sys.exit(failures)


if __name__ == '__main__':
    runtests(*sys.argv[1:])



# -*- encoding: utf-8 -*-
"""
Python setup file for the forex app.

"""
import os
from setuptools import setup, find_packages
import forex as app


dev_requires = [
    'flake8',
]

install_requires = [
    # User should install requirements
]


def read(fname):
    try:
        return open(os.path.join(os.path.dirname(__file__), fname)).read()
    except IOError:
        return ''

setup(
    name="valuehorizon-forex",
    version=app.__version__,
    description=read('DESCRIPTION'),
    long_description=read('README.rst'),
    license='The MIT License',
    platforms=['OS Independent'],
    keywords='django, app, reusable, finance, forex, foreign exchange, valuehorizon',
    author='Quincy Alexander',
    author_email='qalexander@valuehorizon.com',
    url="https://github.com/Valuehorizon/valuehorizon-forex",
    packages=find_packages(),
    include_package_data=True,
    install_requires=install_requires,
    extras_require={
        'dev': dev_requires,
    },
    test_suite="forex.tests.runtests.runtests"
)
